@@ -20,7 +20,7 @@ class ExceptionController extends BaseExceptionController
 
         // For error pages, try to find a template for the specific HTTP status code and format
         if (!$showException) {
-            $template = sprintf('WallabagCoreBundle:Exception:%s.%s.twig', $name, $format);
+            $template = sprintf('@WallabagCore/Exception/%s.%s.twig', $name, $format);
             if ($this->templateExists($template)) {
                 return $template;
             }
